@@ -1,5 +1,4 @@
 import io
-import re
 from pathlib import Path
 from zipfile import ZipFile
 
@@ -15,11 +14,15 @@ from patterns.cli.services.pull import (
 )
 from patterns.configuration.edit import GraphDirectoryEditor, FileOverwriteError
 
-_graph_help = "The name of a graph in your Patterns organization [default: directory name]"
+_graph_help = (
+    "The name of a graph in your Patterns organization [default: directory name]"
+)
 _graph_version_id_help = (
     "The id of the graph version to pull. [default: latest version]"
 )
-_organization_help = "The name of the Patterns organization that the graph was uploaded to"
+_organization_help = (
+    "The name of the Patterns organization that the graph was uploaded to"
+)
 _force_help = "Overwrite existing files without prompting"
 _directory_help = "The directory to create the new graph in. Must not exist."
 _component_help = (
