@@ -1,22 +1,20 @@
 from __future__ import annotations
 
-from enum import Enum
+from requests import Session
 
 from patterns.cli.services.api import Endpoints, post_for_json
 
 
 def trigger_node(
+    graph_uid: str,
     node_id: str,
-    graph_version_uid: str,
-    environment_uid: str,
     execution_type: str,
+    session: Session = None,
 ) -> list[dict]:
     return post_for_json(
-        Endpoints.DEPLOYMENTS_TRIGGER_NODE,
+        Endpoints.trigger_node(graph_uid, node_id),
         json={
-            "node_id": node_id,
-            "environment_uid": environment_uid,
-            "graph_version_uid": graph_version_uid,
             "execution_type": execution_type,
         },
+        session=session,
     )
